@@ -9,7 +9,7 @@
 
 from detector_connector import DetectorKafkaConnector
 
-from shift_definition import ShiftAnalyzeResult
+from .shift_definition import ShiftAnalyzeResult
 
 
 class ShiftDetectorKafkaConnector(DetectorKafkaConnector):
